==> kubernetes-model-policy-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/PodDisruptionBudgetSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.IntOrString;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodDisruptionBudgetSpecFluentImpl<A extends PodDisruptionBudgetSpecFluent<A>> extends BaseFluent<A> implements PodDisruptionBudgetSpecFluent<A>{
  public PodDisruptionBudgetSpecFluentImpl() {
  }
  public PodDisruptionBudgetSpecFluentImpl(PodDisruptionBudgetSpec instance) {
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withMinAvailable(instance.getMinAvailable()); 
    this.withSelector(instance.getSelector()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private IntOrStringBuilder maxUnavailable;
  private IntOrStringBuilder minAvailable;
  private LabelSelectorBuilder selector;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public IntOrString buildMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public A withMaxUnavailable(IntOrString maxUnavailable) {
    _visitables.get("maxUnavailable").remove(this.maxUnavailable);
    if (maxUnavailable!=null){ this.maxUnavailable= new IntOrStringBuilder(maxUnavailable); _visitables.get("maxUnavailable").add(this.maxUnavailable);} else { this.maxUnavailable = null; _visitables.get("maxUnavailable").remove(this.maxUnavailable); } return (A) this;
  }
  public Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  public A withNewMaxUnavailable(Object value) {
    return (A)withMaxUnavailable(new IntOrString(value));
  }
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailable() {
    return new PodDisruptionBudgetSpecFluentImpl.MaxUnavailableNestedImpl();
  }
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item) {
    return new PodDisruptionBudgetSpecFluentImpl.MaxUnavailableNestedImpl(item);
  }
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable());
  }
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): new IntOrStringBuilder().build());
  }
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item) {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMinAvailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMinAvailable() {
    return this.minAvailable!=null ?this.minAvailable.build():null;
  }
  public IntOrString buildMinAvailable() {
    return this.minAvailable!=null ?this.minAvailable.build():null;
  }
  public A withMinAvailable(IntOrString minAvailable) {
    _visitables.get("minAvailable").remove(this.minAvailable);
    if (minAvailable!=null){ this.minAvailable= new IntOrStringBuilder(minAvailable); _visitables.get("minAvailable").add(this.minAvailable);} else { this.minAvailable = null; _visitables.get("minAvailable").remove(this.minAvailable); } return (A) this;
  }
  public Boolean hasMinAvailable() {
    return this.minAvailable != null;
  }
  public A withNewMinAvailable(Object value) {
    return (A)withMinAvailable(new IntOrString(value));
  }
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailable() {
    return new PodDisruptionBudgetSpecFluentImpl.MinAvailableNestedImpl();
  }
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailableLike(IntOrString item) {
    return new PodDisruptionBudgetSpecFluentImpl.MinAvailableNestedImpl(item);
  }
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editMinAvailable() {
    return withNewMinAvailableLike(getMinAvailable());
  }
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailable() {
    return withNewMinAvailableLike(getMinAvailable() != null ? getMinAvailable(): new IntOrStringBuilder().build());
  }
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailableLike(IntOrString item) {
    return withNewMinAvailableLike(getMinAvailable() != null ? getMinAvailable(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public LabelSelector buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public A withSelector(LabelSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new LabelSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  public Boolean hasSelector() {
    return this.selector != null;
  }
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelector() {
    return new PodDisruptionBudgetSpecFluentImpl.SelectorNestedImpl();
  }
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelectorLike(LabelSelector item) {
    return new PodDisruptionBudgetSpecFluentImpl.SelectorNestedImpl(item);
  }
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new LabelSelectorBuilder().build());
  }
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelectorLike(LabelSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodDisruptionBudgetSpecFluentImpl that = (PodDisruptionBudgetSpecFluentImpl) o;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    if (minAvailable != null ? !minAvailable.equals(that.minAvailable) :that.minAvailable != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxUnavailable,  minAvailable,  selector,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (maxUnavailable != null) { sb.append("maxUnavailable:"); sb.append(maxUnavailable + ","); }
    if (minAvailable != null) { sb.append("minAvailable:"); sb.append(minAvailable + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MaxUnavailableNestedImpl<N> extends IntOrStringFluentImpl<PodDisruptionBudgetSpecFluent.MaxUnavailableNested<N>> implements PodDisruptionBudgetSpecFluent.MaxUnavailableNested<N>,Nested<N>{
    MaxUnavailableNestedImpl(IntOrString item) {
      this.builder = new IntOrStringBuilder(this, item);
    }
    MaxUnavailableNestedImpl() {
      this.builder = new IntOrStringBuilder(this);
    }
    IntOrStringBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withMaxUnavailable(builder.build());
    }
    public N endMaxUnavailable() {
      return and();
    }
    
  }
  class MinAvailableNestedImpl<N> extends IntOrStringFluentImpl<PodDisruptionBudgetSpecFluent.MinAvailableNested<N>> implements PodDisruptionBudgetSpecFluent.MinAvailableNested<N>,Nested<N>{
    MinAvailableNestedImpl(IntOrString item) {
      this.builder = new IntOrStringBuilder(this, item);
    }
    MinAvailableNestedImpl() {
      this.builder = new IntOrStringBuilder(this);
    }
    IntOrStringBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withMinAvailable(builder.build());
    }
    public N endMinAvailable() {
      return and();
    }
    
  }
  class SelectorNestedImpl<N> extends LabelSelectorFluentImpl<PodDisruptionBudgetSpecFluent.SelectorNested<N>> implements PodDisruptionBudgetSpecFluent.SelectorNested<N>,Nested<N>{
    SelectorNestedImpl(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new LabelSelectorBuilder(this);
    }
    LabelSelectorBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-policy-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/PodDisruptionBudgetSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.IntOrString;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodDisruptionBudgetSpecFluentImpl<A extends PodDisruptionBudgetSpecFluent<A>> extends BaseFluent<A> implements PodDisruptionBudgetSpecFluent<A>{
  public PodDisruptionBudgetSpecFluentImpl() {
  }
  public PodDisruptionBudgetSpecFluentImpl(PodDisruptionBudgetSpec instance) {
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withMinAvailable(instance.getMinAvailable()); 
    this.withSelector(instance.getSelector()); 
    this.withUnhealthyPodEvictionPolicy(instance.getUnhealthyPodEvictionPolicy()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private IntOrStringBuilder maxUnavailable;
  private IntOrStringBuilder minAvailable;
  private LabelSelectorBuilder selector;
  private String unhealthyPodEvictionPolicy;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public IntOrString buildMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public A withMaxUnavailable(IntOrString maxUnavailable) {
    _visitables.get("maxUnavailable").remove(this.maxUnavailable);
    if (maxUnavailable!=null){ this.maxUnavailable= new IntOrStringBuilder(maxUnavailable); _visitables.get("maxUnavailable").add(this.maxUnavailable);} else { this.maxUnavailable = null; _visitables.get("maxUnavailable").remove(this.maxUnavailable); } return (A) this;
  }
  public Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  public A withNewMaxUnavailable(Object value) {
    return (A)withMaxUnavailable(new IntOrString(value));
  }
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailable() {
    return new PodDisruptionBudgetSpecFluentImpl.MaxUnavailableNestedImpl();
  }
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item) {
    return new PodDisruptionBudgetSpecFluentImpl.MaxUnavailableNestedImpl(item);
  }
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable());
  }
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): new IntOrStringBuilder().build());
  }
  public PodDisruptionBudgetSpecFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item) {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildMinAvailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMinAvailable() {
    return this.minAvailable!=null ?this.minAvailable.build():null;
  }
  public IntOrString buildMinAvailable() {
    return this.minAvailable!=null ?this.minAvailable.build():null;
  }
  public A withMinAvailable(IntOrString minAvailable) {
    _visitables.get("minAvailable").remove(this.minAvailable);
    if (minAvailable!=null){ this.minAvailable= new IntOrStringBuilder(minAvailable); _visitables.get("minAvailable").add(this.minAvailable);} else { this.minAvailable = null; _visitables.get("minAvailable").remove(this.minAvailable); } return (A) this;
  }
  public Boolean hasMinAvailable() {
    return this.minAvailable != null;
  }
  public A withNewMinAvailable(Object value) {
    return (A)withMinAvailable(new IntOrString(value));
  }
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailable() {
    return new PodDisruptionBudgetSpecFluentImpl.MinAvailableNestedImpl();
  }
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> withNewMinAvailableLike(IntOrString item) {
    return new PodDisruptionBudgetSpecFluentImpl.MinAvailableNestedImpl(item);
  }
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editMinAvailable() {
    return withNewMinAvailableLike(getMinAvailable());
  }
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailable() {
    return withNewMinAvailableLike(getMinAvailable() != null ? getMinAvailable(): new IntOrStringBuilder().build());
  }
  public PodDisruptionBudgetSpecFluent.MinAvailableNested<A> editOrNewMinAvailableLike(IntOrString item) {
    return withNewMinAvailableLike(getMinAvailable() != null ? getMinAvailable(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public LabelSelector getSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public LabelSelector buildSelector() {
    return this.selector!=null ?this.selector.build():null;
  }
  public A withSelector(LabelSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new LabelSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} else { this.selector = null; _visitables.get("selector").remove(this.selector); } return (A) this;
  }
  public Boolean hasSelector() {
    return this.selector != null;
  }
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelector() {
    return new PodDisruptionBudgetSpecFluentImpl.SelectorNestedImpl();
  }
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> withNewSelectorLike(LabelSelector item) {
    return new PodDisruptionBudgetSpecFluentImpl.SelectorNestedImpl(item);
  }
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new LabelSelectorBuilder().build());
  }
  public PodDisruptionBudgetSpecFluent.SelectorNested<A> editOrNewSelectorLike(LabelSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public String getUnhealthyPodEvictionPolicy() {
    return this.unhealthyPodEvictionPolicy;
  }
  public A withUnhealthyPodEvictionPolicy(String unhealthyPodEvictionPolicy) {
    this.unhealthyPodEvictionPolicy=unhealthyPodEvictionPolicy; return (A) this;
  }
  public Boolean hasUnhealthyPodEvictionPolicy() {
    return this.unhealthyPodEvictionPolicy != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodDisruptionBudgetSpecFluentImpl that = (PodDisruptionBudgetSpecFluentImpl) o;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    if (minAvailable != null ? !minAvailable.equals(that.minAvailable) :that.minAvailable != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    if (unhealthyPodEvictionPolicy != null ? !unhealthyPodEvictionPolicy.equals(that.unhealthyPodEvictionPolicy) :that.unhealthyPodEvictionPolicy != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxUnavailable,  minAvailable,  selector,  unhealthyPodEvictionPolicy,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (maxUnavailable != null) { sb.append("maxUnavailable:"); sb.append(maxUnavailable + ","); }
    if (minAvailable != null) { sb.append("minAvailable:"); sb.append(minAvailable + ","); }
    if (selector != null) { sb.append("selector:"); sb.append(selector + ","); }
    if (unhealthyPodEvictionPolicy != null) { sb.append("unhealthyPodEvictionPolicy:"); sb.append(unhealthyPodEvictionPolicy + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MaxUnavailableNestedImpl<N> extends IntOrStringFluentImpl<PodDisruptionBudgetSpecFluent.MaxUnavailableNested<N>> implements PodDisruptionBudgetSpecFluent.MaxUnavailableNested<N>,Nested<N>{
    MaxUnavailableNestedImpl(IntOrString item) {
      this.builder = new IntOrStringBuilder(this, item);
    }
    MaxUnavailableNestedImpl() {
      this.builder = new IntOrStringBuilder(this);
    }
    IntOrStringBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withMaxUnavailable(builder.build());
    }
    public N endMaxUnavailable() {
      return and();
    }
    
  }
  class MinAvailableNestedImpl<N> extends IntOrStringFluentImpl<PodDisruptionBudgetSpecFluent.MinAvailableNested<N>> implements PodDisruptionBudgetSpecFluent.MinAvailableNested<N>,Nested<N>{
    MinAvailableNestedImpl(IntOrString item) {
      this.builder = new IntOrStringBuilder(this, item);
    }
    MinAvailableNestedImpl() {
      this.builder = new IntOrStringBuilder(this);
    }
    IntOrStringBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withMinAvailable(builder.build());
    }
    public N endMinAvailable() {
      return and();
    }
    
  }
  class SelectorNestedImpl<N> extends LabelSelectorFluentImpl<PodDisruptionBudgetSpecFluent.SelectorNested<N>> implements PodDisruptionBudgetSpecFluent.SelectorNested<N>,Nested<N>{
    SelectorNestedImpl(LabelSelector item) {
      this.builder = new LabelSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new LabelSelectorBuilder(this);
    }
    LabelSelectorBuilder builder;
    public N and() {
      return (N) PodDisruptionBudgetSpecFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}
